==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/shadow.js <==
joo.classLoader.prepare("package ext.config",/* {

import joo.JavaScriptObject;*/

/**
 * Simple class that can provide a shadow effect for any element. Note that the element MUST be absolutely positioned, and the shadow does not provide any shimming. This should be used only in simple cases -- for more advanced functionality that can also provide the same shadow effect, see the <a href="Ext.Layer.html">Ext.Layer</a> class.
 *
 * <p>This class serves as a
 * typed config object for constructor of class Shadow.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.Shadow
 */
{ExtConfig:{target:"ext.Shadow"}},
"public class shadow extends joo.JavaScriptObject",2,function($$private){;return[ 

  "public function shadow",function shadow$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    joo.JavaScriptObject.call(this,config);
  },


  /**
   The shadow display mode. Supports the following options:<div class="mdetail-params"><ul><li><b><tt>sides</tt></b> : Shadow displays on both sides and bottom only</li><li><b><tt>frame</tt></b> : Shadow displays equally on all four sides</li><li><b><tt>drop</tt></b> : Traditional bottom-right drop shadow</li></ul></div>
   */
  "public native function get mode"/*():String*/,

  /**
   * @private
   */
  "public native function set mode"/*(value:String):void*/,

  /**
   The number of pixels to offset the shadow from the element (defaults to <tt>4</tt>)
   */
  "public native function get offset"/*():String*/,

  /**
   * @private
   */
  "public native function set offset"/*(value:String):void*/,


];},[],["joo.JavaScriptObject"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/shadow.js <==
joo.classLoader.prepare("package ext.config",/* {

import joo.JavaScriptObject;*/

/**
 * Simple class that can provide a shadow effect for any element. Note that the element MUST be absolutely positioned, and the shadow does not provide any shimming. This should be used only in simple cases -- for more advanced functionality that can also provide the same shadow effect, see the <a href="Ext.Layer.html">Ext.Layer</a> class.
 *
 * <p>This class serves as a
 * typed config object for constructor of class Shadow.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.Shadow
 */
{ExtConfig:{target:"ext.Shadow"}},
"public class shadow extends joo.JavaScriptObject",2,function($$private){var $1=joo;return[ 

  "public function shadow",function shadow(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.JavaScriptObject.call(this,config);
  },


  /**
   The shadow display mode. Supports the following options:<div class="mdetail-params"><ul><li><b><tt>sides</tt></b> : Shadow displays on both sides and bottom only</li><li><b><tt>frame</tt></b> : Shadow displays equally on all four sides</li><li><b><tt>drop</tt></b> : Traditional bottom-right drop shadow</li></ul></div>
   */
  "public native function get mode"/*():String*/,

  /**
   * @private
   */
  "public native function set mode"/*(value:String):void*/,

  /**
   The number of pixels to offset the shadow from the element (defaults to <tt>4</tt>)
   */
  "public native function get offset"/*():String*/,

  /**
   * @private
   */
  "public native function set offset"/*(value:String):void*/,


undefined];},[],["joo.JavaScriptObject"], "0.8.0", "0.9.12"
);
